@@ -9,14 +9,12 @@
 #'   which provides a one-row summary of model-level statistics.
 #'
 #' @importFrom stats AIC BIC coef confint fitted logLik model.frame
-#' @importFrom stats predict qnorm qt residuals setNames var na.omit
-#' @importFrom stats model.response terms na.pass cooks.distance
-#' @importFrom stats influence rstandard
-#'
+#' @importFrom stats pnorm qnorm qt predict residuals setNames var 
+#' @importFrom stats quantile model.response terms na.pass na.omit
+#' @importFrom stats influence rstandard cooks.distance
 #' @importFrom purrr map_df set_names possibly
 #' @importFrom tibble tibble as_tibble
 #' @importFrom tidyr pivot_longer pivot_wider
-#' @importFrom dplyr select filter mutate mutate_at
 #'
 #' @importFrom utils head
 #' @importFrom glue glue
@@ -28,3 +26,7 @@
 #' @keywords internal
 "_PACKAGE"
 
+# address unused Imports warning from R CMD check
+import_ggplot <- function() {
+  ggplot2::aes()
+}
