@@ -95,7 +95,9 @@ tidy.htest <- function(x, ...) {
   if (!is.null(x$alternative)) {
     ret <- c(ret, alternative = as.character(x$alternative))
   }
-  as_tibble(ret)
+  
+  # convert matrix columns to vector columns (see GH Issue #1081)
+  dplyr::mutate(as_tibble(ret), dplyr::across(where(is.matrix), c))
 }
 
 
@@ -125,6 +127,8 @@ glance.htest <- function(x, ...) tidy(x)
 #' @seealso [augment()], [stats::chisq.test()]
 #' @family htest tidiers
 augment.htest <- function(x, ...) {
+  check_ellipses("newdata", "augment", "htest", ...)
+  
   if (all(c("observed", "expected", "residuals", "stdres") %in% names(x))) {
     return(augment_chisq_test(x, ...))
   }
@@ -178,11 +182,7 @@ augment_chisq_test <- function(x, ...) {
 #' Note also that the columns of group1 and group2 will always be a factor,
 #' even if the original input is (e.g.) numeric.
 #'
-#' @examples
-#'
-#' # feel free to ignore the following line—it allows {broom} to supply 
-#' # examples without requiring the data-supplying package to be installed.
-#' if (requireNamespace("modeldata", quietly = TRUE)) {
+#' @examplesIf rlang::is_installed("modeldata")
 #'
 #' attach(airquality)
 #' Month <- factor(Month, labels = month.abb[5:9])
@@ -200,8 +200,6 @@ augment_chisq_test <- function(x, ...) {
 #'
 #' tidy(pairwise.wilcox.test(compounds, class))
 #' 
-#' }
-#' 
 #' @export
 #' @seealso [stats::pairwise.t.test()], [stats::pairwise.wilcox.test()],
 #'   [tidy()]
